Documentation
¶
Overview ¶
The streamProvider is designed as a future improvement to utilize a data stream, such as WebSocket, which is more efficient than polling for new blocks.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewWebsocketProvider ¶
func NewWebsocketProvider() *streamProvider
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.