mocks

package
v0.0.0-...-6802d5b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 26, 2024 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package mocks is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockIAtomicWriter

type MockIAtomicWriter struct {
	// contains filtered or unexported fields
}

MockIAtomicWriter is a mock of IAtomicWriter interface.

func NewMockIAtomicWriter

func NewMockIAtomicWriter(ctrl *gomock.Controller) *MockIAtomicWriter

NewMockIAtomicWriter creates a new mock instance.

func (*MockIAtomicWriter) AppendBlock

func (m *MockIAtomicWriter) AppendBlock(block *types.Block) error

AppendBlock mocks base method.

func (*MockIAtomicWriter) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockIAtomicWriter) PopLatestBlock

func (m *MockIAtomicWriter) PopLatestBlock() (*types.Block, error)

PopLatestBlock mocks base method.

type MockIAtomicWriterMockRecorder

type MockIAtomicWriterMockRecorder struct {
	// contains filtered or unexported fields
}

MockIAtomicWriterMockRecorder is the mock recorder for MockIAtomicWriter.

func (*MockIAtomicWriterMockRecorder) AppendBlock

func (mr *MockIAtomicWriterMockRecorder) AppendBlock(block interface{}) *gomock.Call

AppendBlock indicates an expected call of AppendBlock.

func (*MockIAtomicWriterMockRecorder) PopLatestBlock

func (mr *MockIAtomicWriterMockRecorder) PopLatestBlock() *gomock.Call

PopLatestBlock indicates an expected call of PopLatestBlock.

type MockIReader

type MockIReader struct {
	// contains filtered or unexported fields
}

MockIReader is a mock of IReader interface.

func NewMockIReader

func NewMockIReader(ctrl *gomock.Controller) *MockIReader

NewMockIReader creates a new mock instance.

func (*MockIReader) EXPECT

func (m *MockIReader) EXPECT() *MockIReaderMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockIReader) GetLatestBlock

func (m *MockIReader) GetLatestBlock() (*types.Block, error)

GetLatestBlock mocks base method.

func (*MockIReader) GetTransactions

func (m *MockIReader) GetTransactions(address string) ([]*types.Transaction, error)

GetTransactions mocks base method.

type MockIReaderMockRecorder

type MockIReaderMockRecorder struct {
	// contains filtered or unexported fields
}

MockIReaderMockRecorder is the mock recorder for MockIReader.

func (*MockIReaderMockRecorder) GetLatestBlock

func (mr *MockIReaderMockRecorder) GetLatestBlock() *gomock.Call

GetLatestBlock indicates an expected call of GetLatestBlock.

func (*MockIReaderMockRecorder) GetTransactions

func (mr *MockIReaderMockRecorder) GetTransactions(address interface{}) *gomock.Call

GetTransactions indicates an expected call of GetTransactions.

type MockIStorage

type MockIStorage struct {
	// contains filtered or unexported fields
}

MockIStorage is a mock of IStorage interface.

func NewMockIStorage

func NewMockIStorage(ctrl *gomock.Controller) *MockIStorage

NewMockIStorage creates a new mock instance.

func (*MockIStorage) AtomicWrite

func (m *MockIStorage) AtomicWrite(arg0 func(storage.IAtomicWriter) error) error

AtomicWrite mocks base method.

func (*MockIStorage) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockIStorage) GetLatestBlock

func (m *MockIStorage) GetLatestBlock() (*types.Block, error)

GetLatestBlock mocks base method.

func (*MockIStorage) GetTransactions

func (m *MockIStorage) GetTransactions(address string) ([]*types.Transaction, error)

GetTransactions mocks base method.

func (*MockIStorage) Subscribe

func (m *MockIStorage) Subscribe(address string) error

Subscribe mocks base method.

func (*MockIStorage) Unsubscribe

func (m *MockIStorage) Unsubscribe(address string) error

Unsubscribe mocks base method.

type MockIStorageMockRecorder

type MockIStorageMockRecorder struct {
	// contains filtered or unexported fields
}

MockIStorageMockRecorder is the mock recorder for MockIStorage.

func (*MockIStorageMockRecorder) AtomicWrite

func (mr *MockIStorageMockRecorder) AtomicWrite(arg0 interface{}) *gomock.Call

AtomicWrite indicates an expected call of AtomicWrite.

func (*MockIStorageMockRecorder) GetLatestBlock

func (mr *MockIStorageMockRecorder) GetLatestBlock() *gomock.Call

GetLatestBlock indicates an expected call of GetLatestBlock.

func (*MockIStorageMockRecorder) GetTransactions

func (mr *MockIStorageMockRecorder) GetTransactions(address interface{}) *gomock.Call

GetTransactions indicates an expected call of GetTransactions.

func (*MockIStorageMockRecorder) Subscribe

func (mr *MockIStorageMockRecorder) Subscribe(address interface{}) *gomock.Call

Subscribe indicates an expected call of Subscribe.

func (*MockIStorageMockRecorder) Unsubscribe

func (mr *MockIStorageMockRecorder) Unsubscribe(address interface{}) *gomock.Call

Unsubscribe indicates an expected call of Unsubscribe.

type MockIWriter

type MockIWriter struct {
	// contains filtered or unexported fields
}

MockIWriter is a mock of IWriter interface.

func NewMockIWriter

func NewMockIWriter(ctrl *gomock.Controller) *MockIWriter

NewMockIWriter creates a new mock instance.

func (*MockIWriter) AtomicWrite

func (m *MockIWriter) AtomicWrite(arg0 func(storage.IAtomicWriter) error) error

AtomicWrite mocks base method.

func (*MockIWriter) EXPECT

func (m *MockIWriter) EXPECT() *MockIWriterMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockIWriter) Subscribe

func (m *MockIWriter) Subscribe(address string) error

Subscribe mocks base method.

func (*MockIWriter) Unsubscribe

func (m *MockIWriter) Unsubscribe(address string) error

Unsubscribe mocks base method.

type MockIWriterMockRecorder

type MockIWriterMockRecorder struct {
	// contains filtered or unexported fields
}

MockIWriterMockRecorder is the mock recorder for MockIWriter.

func (*MockIWriterMockRecorder) AtomicWrite

func (mr *MockIWriterMockRecorder) AtomicWrite(arg0 interface{}) *gomock.Call

AtomicWrite indicates an expected call of AtomicWrite.

func (*MockIWriterMockRecorder) Subscribe

func (mr *MockIWriterMockRecorder) Subscribe(address interface{}) *gomock.Call

Subscribe indicates an expected call of Subscribe.

func (*MockIWriterMockRecorder) Unsubscribe

func (mr *MockIWriterMockRecorder) Unsubscribe(address interface{}) *gomock.Call

Unsubscribe indicates an expected call of Unsubscribe.

Jump to