redisstorage

package
v0.0.0-...-6802d5b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 26, 2024 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

The redisStorage is designed as a future improvement to utilize Redis as a storage, instead of the current in-memory storage. This could bring various benefits, such as persistence, better scalability, different eviction policies, etc. depending on the needs of the application.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewRedisStorage

func NewRedisStorage() *redisStorage

Types

This section is empty.

Jump to