Documentation
¶
Overview ¶
The redisStorage is designed as a future improvement to utilize Redis as a storage, instead of the current in-memory storage. This could bring various benefits, such as persistence, better scalability, different eviction policies, etc. depending on the needs of the application.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRedisStorage ¶
func NewRedisStorage() *redisStorage
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.